/** @type {import('tailwindcss').Config} */
const defaultTheme = require('tailwindcss/defaultTheme');

export default {
  content: ['./index.html', 'src/**/*.{js,ts,jsx,tsx}', '../../libs/*/lib/**/*.{js,ts,jsx,tsx}'],
  theme: {
    extend: {
      fontFamily: {
        inter: ['"Inter"', ...defaultTheme.fontFamily.sans],
      },
      colors: {
        ...defaultTheme.colors,
        entity: {
          // https://www.tailwindshades.com/#color=29.41176470588235%2C100%2C50&step-up=8&step-down=8&hue-shift=5&name=flush-orange&base-stop=6&v=1&overrides=e30%3D
          DEFAULT: '#FF7D00',
          0: '#FFFAF9',
          50: '#FFF3E6',
          100: '#FFE7CC',
          200: '#FFD3A3',
          300: '#FFBF7A',
          400: '#FFA952',
          500: '#FF9429',
          600: '#FF7D00', // primary
          700: '#D66700',
          800: '#AD5200',
          900: '#853E00',
          950: '#703400',
        },
        relation: {
          //https://www.tailwindshades.com/#color=207.97297297297297%2C62.184873949579824%2C46.666666666666664&step-up=9&step-down=10&hue-shift=0&name=mariner&base-stop=6&v=1&overrides=e30%3D
          DEFAULT: '#2D7CC1',
          50: '#EFF6FB',
          100: '#DDEBF7',
          200: '#B7D5EE',
          300: '#92BFE6',
          400: '#6DA9DD',
          500: '#4893D4',
          600: '#2D7CC1',
          700: '#236198',
          800: '#1A476E',
          900: '#102C45',
          950: '#0B1F30',
        },
        line: {
          100: '#dee9f0',
          300: '#ccd6dc',
        },
        logic: {
          DEFAULT: '#A36A30',
          50: '#FBF6F1',
          100: '#F5E9DD',
          200: '#E9D0B6',
          300: '#DEB68E',
          400: '#D29D67',
          500: '#C7843F',
          600: '#A36A30',
          700: '#7C5024',
          800: '#543719',
          900: '#2D1D0D',
          950: '#191007',
        },
        offwhite: {
          DEFAULT: '#F7F9FA',
          100: '#F7F9FA',
          200: '#f4f6f7',
          300: '#d4dce1',
        },
      },
    },
  },
  plugins: [require('@tailwindcss/typography'), require('daisyui')],
  // daisyUI config (optional - here are the default values)
  daisyui: {
    themes: [
      {
        graphpolarisWhite: {
          ...require('daisyui/src/theming/themes')['[data-theme=corporate]'],
          fontFamily: 'inter,ubuntu,courier,ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace',
          primary: '#112646',
          secondary: '#B0B8C2',
          accent: '#FF7D00',
          neutral: '#1c1917',
          'base-100': '#F7F9FA',
          // 'base-200': '#F9FBFC',
          info: '#99622E',
          success: '#2DC177',
          warning: '#eab308',
          error: '#dc2626',

          // "--rounded-box": "0rem", // border radius rounded-box utility class, used in card and other large boxes
          // "--rounded-btn": "0.5rem", // border radius rounded-btn utility class, used in buttons and similar element
          // "--rounded-badge": "1.9rem", // border radius rounded-badge utility class, used in badges and similar
          // "--animation-btn": "0.25s", // duration of animation when you click on button
          // "--animation-input": "0.2s", // duration of animation for inputs like checkbox, toggle, radio, etc
          // "--btn-text-case": "uppercase", // set default text transform for buttons
          // "--btn-focus-scale": "0.95", // scale transform of button when you focus on it
          // "--border-btn": "1px", // border width of buttons
          // "--tab-border": "1px", // border width of tabs
          // "--tab-radius": "0.5rem", // border radius of tabs
        },
      },
      'dark',
      'corporate',
    ], // true: all themes | false: only light + dark | array: specific themes like this ["light", "dark", "cupcake"]
    darkTheme: false, // disabled for now
    // darkTheme: 'dark', // name of one of the included themes for dark mode
    base: true, // applies background color and foreground color for root element by default
    styled: true, // include daisyUI colors and design decisions for all components
    utils: true, // adds responsive and modifier utility classes
    rtl: false, // rotate style direction from left-to-right to right-to-left. You also need to add dir="rtl" to your html tag and install `tailwindcss-flip` plugin for Tailwind CSS.
    prefix: '', // prefix for daisyUI classnames (components, modifiers and responsive class names. Not colors)
    logs: false, // Shows info about daisyUI version and used config in the console when building your CSS
  },
};
