/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

import { Position } from 'reactflow';
import { GeneralDescription, InputNode, MathFilterTypes } from './general';

export const MathFilters: Record<MathFilterTypes, GeneralDescription<MathFilterTypes>> = {
  [MathFilterTypes.EQUAL]: {
    key: 'mathFilterEqual',
    name: 'Equal',
    type: MathFilterTypes.EQUAL,
    description: 'Equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '==', type: 'float' },
    logic: ['==', '@1', '@2'],
  },
  [MathFilterTypes.NOT_EQUAL]: {
    key: 'mathFilterNotEqual',
    name: 'Not Equal',
    type: MathFilterTypes.NOT_EQUAL,
    description: 'Not equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '!=', type: 'float' },
    logic: ['!=', '@1', '@2'],
  },
  [MathFilterTypes.LESS_THAN]: {
    key: 'mathFilterLessThan',
    name: 'Less Than',
    type: MathFilterTypes.LESS_THAN,
    description: 'Less than another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '<', type: 'float' },
    logic: ['<', '@1', '@2'],
  },
  [MathFilterTypes.LESS_THAN_EQUAL]: {
    key: 'mathFilterLessThanOrEqual',
    name: 'Less Than or Equal',
    type: MathFilterTypes.LESS_THAN_EQUAL,
    description: 'Less than or equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '<=', type: 'float' },
    logic: ['<=', '@1', '@2'],
  },
  [MathFilterTypes.GREATER_THAN]: {
    key: 'mathFilterGreaterThan',
    name: 'Greater Than',
    type: MathFilterTypes.GREATER_THAN,
    description: 'Greater than another value',

    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '>', type: 'float' },
    logic: ['>', '@1', '@2'],
  },
  [MathFilterTypes.GREATER_THAN_EQUAL]: {
    key: 'mathFilterGreaterThanOrEqual',
    name: 'Greater Than or Equal',
    type: MathFilterTypes.GREATER_THAN_EQUAL,
    description: 'Greater than or equal to another value',
    numInputs: 2,
    inputs: [
      { name: '1', type: 'float', default: 0 },
      { name: '2', type: 'float', default: 0 },
    ],
    output: { name: '>=', type: 'float' },
    logic: ['>=', '@1', '@2'],
  },
};

/** All available functions in the function bar. */
export const MathFilterArray: Array<GeneralDescription<MathFilterTypes>> = Object.values(MathFilters);
