// import { handles } from '@graphpolaris/shared/lib/querybuilder/usecases';
import { useTheme } from '@mui/material';
import React, { MouseEventHandler, useEffect, useMemo } from 'react';
import { ReactFlow, Handle, Position, getConnectedEdges } from 'reactflow';
import styles from './entitypill.module.scss';
import {
  SchemaReactflowEntityNode,
  Handles,
  toHandleId,
  handleDataFromReactflowToId,
  QueryElementTypes,
  NodeAttribute,
} from '../../../model';
import { SchemaAttribute } from '@graphpolaris/shared/lib/schema';
import { styleHandleMap } from '../../utils';
import { useQuerybuilderGraph } from '@graphpolaris/shared/lib/data-access';

/**
 * Component to render an entity flow element
 * @param {NodeProps} param0 The data of an entity flow element.
 */
export const EntityFlowElement = React.memo((node: SchemaReactflowEntityNode) => {
  const theme = useTheme();
  // console.log('EntityFlowElement', node);

  const data = node.data;
  const forceOpen: boolean = false;
  if (!data.leftRelationHandleId) throw new Error('EntityFlowElement: data.leftRelationHandleId is undefined');
  if (!data.rightRelationHandleId) throw new Error('EntityFlowElement: data.rightRelationHandleId is undefined');

  const graph = useQuerybuilderGraph();
  const attributeEdges = useMemo(
    () => graph.edges.filter((edge) => edge.source === node.id && !!edge?.attributes?.sourceHandleData.attributeType),
    [graph]
  );

  const [hovered, setHovered] = React.useState(false);
  const [handleBeingDragged, setHandleBeingDragged] = React.useState(-1);

  // TODO: Change flow element width when text overflows
  const animation = styles.entityFade; // TODO: Check if correct

  const onMouseEnter = (event: React.MouseEvent) => {
    setHovered(true);
  };

  const onMouseLeave = (event: React.MouseEvent) => {
    setHovered(false);
  };

  const onHandleMouseDown = (attribute: NodeAttribute, i: number, event: React.MouseEvent) => {
    setHandleBeingDragged(i);
    window.addEventListener('mouseup', onHandleMouseUp, true);
  };

  const onHandleMouseUp = () => {
    setHandleBeingDragged(-1);
    window.removeEventListener('mouseup', onHandleMouseUp, true);
  };

  const onConnect = (params: any) => {
    console.log('EntityPill onConnect', params);
  };

  const showingDropdown = hovered || handleBeingDragged !== -1 || attributeEdges.length > 0;

  return (
    <div
      className={`${styles.entity} ${animation} query_builder-entity`}
      onMouseEnter={onMouseEnter}
      onMouseLeave={onMouseLeave}
      style={
        {
          // borderColor: theme.palette.custom.elements.entityBase[0],
        }
      }
    >
      <Handle
        // id={getHandleId(data.name, data.type, Handles.ToRelation, '')}
        id={toHandleId(data.leftRelationHandleId)}
        type="target"
        position={Position.Left}
        className={styles.handle_to_relation}
      />
      <Handle
        // id={getHandleId(data.name, data.type, Handles.ToRelation, '')}
        id={toHandleId(data.rightRelationHandleId)}
        type="source"
        position={Position.Right}
        className={styles.handle_to_relation}
      />
      {/* <Handle
        id={Handles.ToAttribute}
        type="target"
        position={Position.Bottom}
        className={
          styles.ToAttributeHandle +
          ' ' +
          (false ? styles.handleConnectedFill : '')
        }
      />
      <Handle
        id={Handles.ReceiveFunction}
        type="target"
        position={Position.Bottom}
        className={
          styles.ReceiveFunctionHandle +
          ' ' +
          (false ? styles.handleConnectedFill : '')
        }
      /> */}

      <div
        className={styles.title}
        style={{
          backgroundColor: theme.palette.custom.elements.entityBase[0],
        }}
      >
        {data.name}
      </div>
      {/* <div className={styles.entityWrapper}>
        <span className={styles.entitySpan}>{data.name}</span>
      </div> */}
      {data?.attributes && (
        <div className={styles.content + ' ' + (showingDropdown || forceOpen || hovered ? styles.content_display : '')}>
          {data.attributes
            .filter(
              (attribute, i) =>
                forceOpen ||
                hovered ||
                handleBeingDragged === i ||
                (attributeEdges.some(
                  (edge) =>
                    edge?.attributes?.sourceHandleData &&
                    toHandleId(edge?.attributes?.sourceHandleData) === handleDataFromReactflowToId(node, attribute)
                ) &&
                  !!attribute.handleData.attributeName)
            )
            .map((attribute, i) => (
              <div
                key={(attribute.handleData.attributeName || '') + i}
                onMouseDown={(event: React.MouseEvent) => {
                  onHandleMouseDown(attribute, i, event);
                }}
              >
                {attribute.handleData.attributeName}
                <Handle
                  id={handleDataFromReactflowToId(node, attribute)}
                  type="source"
                  position={Position.Right}
                  className={
                    (attribute.handleData.attributeType ? styleHandleMap[attribute.handleData.attributeType] : '') +
                    ' ' +
                    styles.io +
                    ' ' +
                    styles.io_right
                  }
                ></Handle>
              </div>
            ))}
        </div>
      )}
    </div>
  );
});

EntityFlowElement.displayName = 'EntityFlowElement';

export default EntityFlowElement;
