/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/
import React, { useState } from 'react';
import { Handle, Position } from 'reactflow';
import styles from './functionpill.module.scss';
import { useTheme } from '@mui/material';
import { Handles } from '../../../model';

const countArgs = (data: any) => {
  if (data !== undefined) {
    let count = 0;

    for (const name in data.args) {
      if (data.args[name].visible) {
        count++;
      }
    }
    return count;
  }
  return 1;
};

/**
 * Capitalize the first letter of a string.
 * @param string This is the given string.
 * @returns {string} This is the modified string.
 */
export const capitalizeFirstLetter = (string: string) => {
  return string.charAt(0).toUpperCase() + string.slice(1);
};

/**
 * Component to render a relation flow element
 * @param { FlowElement<FunctionData>} param0 The data of a relation flow element.
 */
export default function RelationFlowElement({ data }: any) {
  const [read, setRead] = useState(true);
  const theme = useTheme();

  const numOfArgs = countArgs(data);
  const height = numOfArgs * 20;

  const _onKeyDown = (event: any): void => {
    if (event.key == 'Enter') setRead(true);
  };

  const getArgs = (styles: any, data: any, setRead: any) => {
    let rows: JSX.Element[] = [];

    if (data != undefined) {
      let index = 0;

      for (const name in data.args) {
        const item = data.args[name];
        if (item.visible) {
          rows.push(
            <span className={styles.functionHandleFiller} key={name}>
              <span className={styles.functionSpan}>{capitalizeFirstLetter(name)}</span>
              <Handle
                id={Handles.FunctionBase + name}
                type="source"
                position={Position.Top}
                className={styles.functionHandle + ' ' + (false ? styles.handleConnectedFill : '')}
                style={{
                  visibility: item.connectable ? 'inherit' : 'hidden',
                }}
              />
              {item.value !== undefined && (
                <input
                  className={styles.functionInput}
                  style={{ maxWidth: 50 }}
                  type="string"
                  placeholder={'?'}
                  value={item.value}
                  onChange={(e) => {
                    if (item.value != undefined) {
                      item.value = e.target.value;
                      //TODO restore SetElementsUseCase.updateFunctionCompleteness(data);
                    }
                  }}
                  onDoubleClick={() => {
                    setRead(false);
                  }}
                  onBlur={() => {
                    setRead(true);
                  }}
                  onKeyDown={_onKeyDown}
                ></input>
              )}
            </span>
          );
          index++;
        }
      }
    }

    return rows;
  };

  const rows = getArgs(styles, data, setRead);
  const entity = undefined; //TODO fix: data !== undefined ? data.entityName : undefined;

  return (
    <div>
      <div
        className={styles.function}
        style={{
          minHeight: height,
          background: theme.palette.custom.nodesBase[0],
          borderTop: `4px solid ${theme.palette.custom.nodesBase[0]}`,
          borderBottom: `6px solid ${theme.palette.custom.elements.function[0]}`,
        }}
      >
        <div className={styles.functionWrapper}>{rows}</div>
      </div>
      <div className={`${styles.entity} entityWrapper ${entity === undefined ? 'hidden' : ''}`}>
        <Handle
          id={Handles.FromAttribute}
          type="source"
          position={Position.Bottom}
          className={styles.entityHandleLeft + ' ' + (false ? styles.handleConnectedFill : '')}
        />
        <Handle
          id={Handles.ToAttribute}
          type="source"
          position={Position.Bottom}
          className={styles.entityHandleBottom + ' ' + (false ? styles.handleConnectedFill : '')}
        />
        <div className={styles.entityWrapper}>
          <span className={styles.entitySpan}>{entity ? entity : ''}</span>
        </div>
      </div>
    </div>
  );
}
